##
##  goaccess.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg 1.9.2
%define       V_dist 1.9.2

#   package information
Name:         goaccess
Summary:      Apache Access Log Real-Time Reporting
URL:          https://goaccess.io/
Vendor:       Gerardo Orellana
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Web
License:      GPL
Version:      %{V_opkg}
Release:      20240412

#   list of sources
Source0:      http://tar.goaccess.io/goaccess-%{V_dist}.tar.gz
Patch0:       goaccess.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, pkgconfig, gcc
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  ncurses, glib, geoip
PreReq:       ncurses, glib, geoip

%description
    GoAccess is an open source real-time Apache web log analyzer and
    interactive viewer that runs in a terminal and provides fast and
    valuable HTTP statistics for system administrators that require a
    visual report on the fly.

%track
    prog goaccess = {
        version   = %{V_dist}
        url       = https://goaccess.io/download
        regex     = goaccess-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n goaccess-%{V_dist}
    %patch -p0

%build
    CC="%{l_cc} `pkg-config --cflags glib-2.0` -pthread" \
    CFLAGS="%{l_cflags -O} `pkg-config --cflags-only-other glib-2.0`" \
    CPPFLAGS="%{l_cppflags} `pkg-config --cflags-only-I glib-2.0`" \
    LDFLAGS="%{l_ldflags} `pkg-config --libs-only-L glib-2.0`" \
    LIBS="`pkg-config --libs-only-l glib-2.0`" \
    ./configure \
        --prefix=%{l_prefix} \
        --sysconfdir=%{l_prefix}/etc/goaccess \
        --mandir=%{l_prefix}/man
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/goaccess/*'

%files -f files

%clean

